import openpyxl

from myrequests import log_decorator
from myrequests.common.read_json import read_json
from myrequests.common.read_system_ini import ReadSystemIni
from myrequests.common.read_user_ini import ReadUserIni


class ReadExcel:
    @log_decorator
    def __init__(self,username):
        self.ini=ReadUserIni(username)
        self.system_ini=ReadSystemIni()
        self.case_data_dict = read_json(self.ini.get_file_path("case"))
        self.expect_data_dict = read_json(self.ini.get_file_path("expect"))
        self.sql_data_dict = read_json(self.ini.get_file_path("sql"))

        wb = openpyxl.load_workbook(self.ini.get_file_path("excel"))
        self.ws = wb[self.ini.get_table_name("table_name")]

    @log_decorator
    def __get_cell_value(self, column: str, row: int):
        """根据行或列，获取指定单元格数据"""
        cell_value = self.ws[column + str(row)].value
        if isinstance(cell_value, str) and len(cell_value.strip()) > 0:
            return cell_value.strip()

    @log_decorator
    def module_name(self, row):
        """根据行，获取模块名称"""
        return self.__get_cell_value('b', row)

    @log_decorator
    def api_name(self, row):
        """根据行，获取接口名称"""
        return self.__get_cell_value('c', row)

    @log_decorator
    def case_req(self, row):
        """根据行，获取用例的请求方法"""
        return self.__get_cell_value('f', row)

    @log_decorator
    def case_url(self, row):
        """根据行，获取用例的url"""
        value = self.__get_cell_value('g', row)
        if value:
            return self.system_ini.get_host('host') + value

    @log_decorator
    def case_mime(self, row):
        """根据行，获取用例的媒体类型"""
        value = self.__get_cell_value('h', row)
        if value:
         return value.lower()

    @log_decorator
    def case_data(self, row):
        """根据行，获取用例数据"""
        case_data_key = self.__get_cell_value('i', row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if case_data_key and module_name and api_name:
            return self.case_data_dict[module_name][api_name][case_data_key]

    @log_decorator
    def expect_data(self, row):
        """根据行，获取期望数据"""
        expect_data_key = self.__get_cell_value('j', row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if expect_data_key and module_name and api_name:
            return self.expect_data_dict[module_name][api_name][expect_data_key]

    @log_decorator
    def sql_data(self, row):
        """根据行，获取sql语句"""
        sql_data_key = self.__get_cell_value('l', row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if sql_data_key and module_name and api_name:
            return self.sql_data_dict[module_name][api_name][sql_data_key]

    @log_decorator
    def sql_type(self, row):
        """根据行，获取sql语句的类型"""
        value = self.__get_cell_value('k', row)
        if value:
            return value.lower()

    @log_decorator
    def update_key(self, row):
        """根据行，获取更新的key"""
        return self.__get_cell_value('m', row)

    @log_decorator
    def get_data(self):
        """获取所以的测试数据，存放在一个二维列表中"""
        list_data = []
        for row in range(2, self.ws.max_row + 1):
            req = self.case_req(row)
            url = self.case_url(row)
            mime = self.case_mime(row)
            case = self.case_data(row)
            expect = self.expect_data(row)
            sql_type = self.sql_type(row)
            sql_data = self.sql_data(row)
            update_key = self.update_key(row)

            if req and url and expect:
                list_data.append([req, url, mime, case, expect, sql_type, sql_data, update_key])
        else:
            return list_data

if __name__ == '__main__':
    excel = ReadExcel("lh")
    print(excel.get_data())
